# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand

class DataCommandBase(System.IDisposable):  # Class
    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def Dispose(self) -> None: ...
    def Undo(self) -> Any: ...

class DeleteCompoundGraphicsRange(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        ds: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        compoundGraphicsID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...

class DeleteFormatting(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        ds: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        formattingID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...

class DeletePrePostProcess(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        ds: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        prePostProcessID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewCalibrationGraphics(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewCompoundGraphicsRange(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        ds: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        compoundGraphicsID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewFormatting(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        formattingID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewGraphicsRange(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewPeakChromatogramGraphics(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewPeakQualifiersGraphics(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewPeakSpectrumGraphics(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewPrePostProcess(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        prePostProcessID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewSampleChromatogramGraphics(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewUnknownsIonPeakGraphicsProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewUnknownsSampleChromatogramGraphics(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class NewUnknownsSpectrumGraphicsProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Undo(self) -> Any: ...

class SetCalibrationGraphicsProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetCompoundGraphicsRangeProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        compoundGraphicsID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetFormattingProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        formattingID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetGraphicsRangeProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetPeakChromatogramGraphicsProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetPeakQualifiersGraphicsProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetPeakSpectrumGraphicsProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetPrePostProcessProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        prePostProcessID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetPropertyBase(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...

class SetReportProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        name: str,
        value_: Any,
    ) -> None: ...
    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...

class SetSampleChromatogramGraphicsProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetUnknownsIonPeakGraphicsProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetUnknownsSampleChromatogramGraphicsProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        name: str,
        value_: Any,
    ) -> None: ...

class SetUnknownsSpectrumGraphicsProperty(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.DataCommand.SetPropertyBase,
):  # Class
    def __init__(
        self,
        dataset: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
        name: str,
        value_: Any,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Signal
from .Controls2 import IPropertyPage
from .Toolbar import IToolbarsManager, IToolHandler, IToolState, ToolbarsManagerBase
from .UIScriptIF import IChromatogramInformation, IUIState
from .UIUtils import PlotPageSettings, PlotPrintDocument

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation

class ChromForm(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self) -> None: ...

    ChromView: (
        Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationView
    )  # readonly
    GridView: (
        Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationGridView
    )  # readonly
    HeadToTail: bool
    LinkXAxes: bool
    LinkYAxes: bool
    MaxNumVisibleRows: int
    Overlay: bool
    ToolbarsManager: IToolbarsManager  # readonly
    UIContext: (
        Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationUIContext
    )  # readonly

    def Initialize(
        self,
        uiState: IUIState,
        dataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator,
    ) -> None: ...
    def AutoScaleY(self) -> None: ...
    def CanAutoScale(self) -> bool: ...
    def Copy(self) -> None: ...
    def AutoScaleX(self) -> None: ...
    def CanCopy(self) -> bool: ...
    def CreatePropertyPages(self) -> List[IPropertyPage]: ...
    def AutoScaleXY(self) -> None: ...
    def CanCreateCompound(self) -> bool: ...
    @overload
    @staticmethod
    def CreateCompound() -> None: ...
    @overload
    @staticmethod
    def CreateCompound(
        uiState: IUIState,
        chromView: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.ChromView,
    ) -> None: ...

    Initialized: System.EventHandler  # Event

class ChromGridView(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationGridView,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.DataGridView,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self) -> None: ...

    UIContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.UIContext
    )

    def Copy(self) -> None: ...
    def UpdateItems(self) -> None: ...
    def CanCopy(self) -> bool: ...

class ChromItem(
    System.IComparable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.ChromItem
    ],
    Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationItem,
):  # Class
    BatchID: int
    Color: System.Drawing.Color
    DataFileName: str
    InstrumentName: str
    MSScanType: Optional[Agilent.MassSpectrometry.DataAnalysis.MSScanType]
    SampleID: int
    SampleName: str
    Signal: Signal

    def Equals(self, obj: Any) -> bool: ...
    def GetHashCode(self) -> int: ...
    def CompareTo(
        self,
        item: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.ChromItem,
    ) -> int: ...
    def Clone(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.ChromItem
    ): ...

class ChromView(
    Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationView,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.IBindableComponent,
    System.ComponentModel.IComponent,
    System.Windows.Forms.IDropTarget,
    Agilent.MassSpectrometry.GUI.Plot.PlotControl,
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.Layout.IArrangedElement,
    System.ComponentModel.ISupportInitialize,
    Agilent.MassSpectrometry.GUI.Plot.ICustomDrawPeakLabelsEx,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
):  # Class
    def __init__(self) -> None: ...

    LinkXAxes: bool
    LinkYAxes: bool
    MaxVisibleRowsPerPage: int
    Mirror: bool
    Overlay: bool
    PlotControl: Agilent.MassSpectrometry.GUI.Plot.PlotControl  # readonly
    UIContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.UIContext
    )

    def DrawLabel(
        self,
        plotPane: Agilent.MassSpectrometry.GUI.Plot.PlotPane,
        font: System.Drawing.Font,
        rect: System.Drawing.RectangleF,
        color: System.Drawing.Color,
        text: str,
        x: float,
        y: float,
        series: int,
        peakIndex: int,
    ) -> None: ...
    def UpdateHighlight(self) -> None: ...
    def AutoScaleY(self) -> None: ...
    def CanAutoScale(self) -> bool: ...
    def Copy(self) -> None: ...
    def GetAutoScaleRangeY(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane, minX: float, maxX: float
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def UIContext_ItemHighlightChanged(
        self, sender: Any, e: System.EventArgs
    ) -> None: ...
    def AutoScaleX(self) -> None: ...
    def CanCopy(self) -> bool: ...
    def InitConfiguration(self) -> None: ...
    def AutoScaleXY(self) -> None: ...
    def UpdatePeaks(self) -> None: ...
    def MeasureLabel(
        self,
        plotPane: Agilent.MassSpectrometry.GUI.Plot.PlotPane,
        font: System.Drawing.Font,
        text: str,
        x: float,
        y: float,
        series: int,
        peakIndex: int,
    ) -> System.Drawing.RectangleF: ...
    def UpdateData(self, keepScale: bool) -> None: ...

class ColorCell(
    System.IDisposable, System.ICloneable, System.Windows.Forms.DataGridViewCell
):  # Class
    def __init__(self) -> None: ...

    ValueType: System.Type  # readonly

class ColorColumn(
    System.ICloneable,
    System.IDisposable,
    System.Windows.Forms.DataGridViewColumn,
    System.ComponentModel.IComponent,
):  # Class
    def __init__(self) -> None: ...

class DefaultEventManipulator(
    Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator,
    System.IDisposable,
    Agilent.MassSpectrometry.GUI.Plot.DefaultEventManipulatorBase,
):  # Class
    def OnMouseUp(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnMouseMove(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnMouseDown(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...

class ExportToSampleFoldersDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...

    FileName: str  # readonly

class GraphicsRangeDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, ichrominfo: IChromatogramInformation) -> None: ...
    def Initialize(self, ichrominfo: IChromatogramInformation) -> None: ...
    def PerformRanges(self, ichrominfo: IChromatogramInformation) -> None: ...

class PlotData(
    Agilent.MassSpectrometry.GUI.Plot.IPlotData,
    Agilent.MassSpectrometry.GUI.Plot.IPeakData,
):  # Class
    def GetPointCount(self, series: int) -> int: ...
    def GetSeries(
        self, index: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.SeriesData
    ): ...
    def GetSeriesCount(self) -> int: ...
    def DisplaySeries(self, series: int) -> bool: ...
    def DisplayLabel(
        self, series: int, peak: int, label: str, color: System.Drawing.Color
    ) -> bool: ...
    def GetPeakCount(self, series: int) -> int: ...
    def GetPeak(self, series: int, peak: int, x: float, y: float) -> None: ...
    def GetPoint(self, series: int, pointIndex: int, x: float, y: float) -> None: ...
    def DisplayMarker(
        self, series: int, peak: int, marker: Agilent.MassSpectrometry.GUI.Plot.Marker
    ) -> bool: ...
    def GetSeriesLineStyle(
        self,
        series: int,
        mode: Agilent.MassSpectrometry.GUI.Plot.PlotModes,
        color: System.Drawing.Color,
        style: System.Drawing.Drawing2D.DashStyle,
        width: int,
    ) -> None: ...
    def Fill(
        self,
        series: int,
        peak: int,
        startPlotIndex: int,
        endPlotIndex: int,
        startBaselineX: float,
        startBaselineY: float,
        endBaselineX: float,
        endBaselineY: float,
        baselineColor: System.Drawing.Color,
        fillColor: System.Drawing.Color,
    ) -> bool: ...

class PrintDoc(
    System.IDisposable, System.ComponentModel.IComponent, PlotPrintDocument
):  # Class
    def __init__(
        self,
        form: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.ChromForm,
        printerSettings: System.Drawing.Printing.PrinterSettings,
        pageSettings: PlotPageSettings,
        preview: bool,
    ) -> None: ...
    def GetNumPages(self) -> int: ...

class PropertiesControl(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UserControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    IPropertyPage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(
        self,
        chromView: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.ChromView,
    ) -> None: ...

    DisplayName: str
    IsDirty: bool  # readonly

    def SetActive(self) -> None: ...
    def DoDefault(self) -> None: ...
    def Apply(self) -> None: ...

    PageChanged: System.EventHandler  # Event

class SeriesData:  # Class
    Item: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.ChromItem
    )  # readonly

class ToolHandlerEdit(IToolHandler):  # Class
    def __init__(self) -> None: ...
    def Execute(self, toolState: IToolState, objUiState: Any) -> None: ...
    def SetState(self, toolState: IToolState, objUiState: Any) -> None: ...

class ToolHandlerFile(IToolHandler):  # Class
    def __init__(self) -> None: ...
    def Execute(self, toolState: IToolState, objUiState: Any) -> None: ...
    def SetState(self, toolState: IToolState, objUiState: Any) -> None: ...

class ToolHandlerView(IToolHandler):  # Class
    def __init__(self) -> None: ...
    def Execute(self, toolState: IToolState, objUiState: Any) -> None: ...
    def SetState(self, toolState: IToolState, objUiState: Any) -> None: ...

class ToolbarsManager(
    System.ComponentModel.ISupportInitialize,
    System.IDisposable,
    ToolbarsManagerBase,
    System.Windows.Forms.IMessageFilter,
    IToolbarsManager,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def RegisterScriptToolHandler(
        self, tool: str, module: str, setState: str, execute: str
    ) -> None: ...

class UIContext(
    System.IDisposable,
    Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationUIContext,
):  # Class
    def __init__(
        self,
        form: Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationWindow,
    ) -> None: ...

    DataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator
    ItemCount: int  # readonly
    Items: List[
        Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationItem
    ]  # readonly
    VisibleItemCount: int  # readonly

    def UpdateItems(self) -> None: ...
    def SetVisible(
        self,
        items: List[
            Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationItem
        ],
        visible: bool,
    ) -> None: ...
    def GetItem(
        self, index: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.ChromItem
    ): ...
    def GetVisibleItem(
        self, index: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromatogramInformation.ChromItem
    ): ...
    def IsVisible(
        self, item: Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationItem
    ) -> bool: ...
    def OnItemColorChanged(self, e: System.EventArgs) -> None: ...
    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Models import IAppCommandContext, ICalibrationRange

# Stubs for namespace: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Commands

class AddCalibrationRange(
    System.IDisposable,
    Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Commands.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: IAppCommandContext,
        targetCompoundID: int,
        targetIonGroupID: int,
        minConcentration: Optional[float],
        maxConcentration: Optional[float],
    ) -> None: ...
    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...

class AddQualifierToCalibrationRange(
    System.IDisposable,
    Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Commands.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: IAppCommandContext,
        targetCompoundID: int,
        calibrationRangeID: int,
        ionGroupID: int,
    ) -> None: ...
    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...

class AppCommandBase(
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
    Agilent.MassSpectrometry.CommandModel.CommandBase,
):  # Class
    AppCommandContext: IAppCommandContext  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...

class AppCommandContext(
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.CommandHistory,
    Agilent.MassSpectrometry.CommandModel.Model.ICommandHistory,
    IAppCommandContext,
):  # Class
    def __init__(self) -> None: ...

    BatchGlobalFeatureAnalysis: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.DynamicQuant.BatchGlobalFeatureAnalysis
    )  # readonly
    IsBatchOpen: bool  # readonly
    MethodDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDataSet
    )  # readonly
    QuantAppCommandContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AppCommandContext
    )  # readonly

    def RemoveCalibrationRange(
        self, targetCompoundID: int, calibrationRangeID: int
    ) -> None: ...
    def CloseBatch(self) -> None: ...
    def NewCalibrationRange(self, targetCompoundID: int) -> ICalibrationRange: ...
    def SaveMethod(self, pathName: str) -> None: ...
    def Analyze(self) -> None: ...
    def AddCalibrationRange(self, range: ICalibrationRange) -> None: ...
    def OpenBatch(self, batchFolder: str, batchFile: str, analyze: bool) -> None: ...
    @staticmethod
    def CalcAverageResponseRatio(
        target: Agilent.MassSpectrometry.DataAnalysis.Quantitative.DynamicQuant.ICrossSampleIonGroup,
        qualifier: Agilent.MassSpectrometry.DataAnalysis.Quantitative.DynamicQuant.ICrossSampleIonGroup,
    ) -> float: ...
    def GetCalibrationRanges(
        self, targetCompoundID: int
    ) -> List[ICalibrationRange]: ...
    @staticmethod
    def CalcAverateMZ(
        ionGroup: Agilent.MassSpectrometry.DataAnalysis.Quantitative.DynamicQuant.ICrossSampleIonGroup,
    ) -> float: ...
    def GetCalibrationRange(
        self, targetCompoundID: int, calibrationRangeID: int
    ) -> ICalibrationRange: ...

    Analyzed: System.EventHandler  # Event
    Analyzing: System.EventHandler  # Event
    BatchClosed: System.EventHandler  # Event
    BatchOpened: System.EventHandler  # Event
    CalibrationRangesChanged: System.EventHandler  # Event
    Progress: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ProgressEventArgs
    ]  # Event

class CloseBatch(
    System.IDisposable,
    Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Commands.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: IAppCommandContext) -> None: ...
    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...

class OpenBatch(
    System.IDisposable,
    Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Commands.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: IAppCommandContext,
        batchFolder: str,
        batchFile: str,
        analyze: bool,
    ) -> None: ...
    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...

class SaveMethod(
    System.IDisposable,
    Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Commands.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: IAppCommandContext, methodPath: str) -> None: ...
    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.CommandModel.Model

class CommandType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Data: Agilent.MassSpectrometry.CommandModel.Model.CommandType = (
        ...
    )  # static # readonly
    UndoRedo: Agilent.MassSpectrometry.CommandModel.Model.CommandType = (
        ...
    )  # static # readonly
    View: Agilent.MassSpectrometry.CommandModel.Model.CommandType = (
        ...
    )  # static # readonly

class ICodeDomExpandParameter(
    Agilent.MassSpectrometry.CommandModel.Model.ICodeDomParameter
):  # Interface
    def GetPreCommandStatements(
        self, counter: int
    ) -> System.CodeDom.CodeStatementCollection: ...

class ICodeDomParameter(object):  # Interface
    def GetExpression(self) -> System.CodeDom.CodeExpression: ...

class ICommand(System.IDisposable):  # Interface
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def Execute(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...

class ICommandHistory(System.IDisposable):  # Interface
    CanRedo: bool  # readonly
    CanUndo: bool  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def RevokeLogListener(
        self, listener: Agilent.MassSpectrometry.CommandModel.Model.ILogListener
    ) -> None: ...
    def Clear(self) -> None: ...
    def RegisterLogListener(
        self, listener: Agilent.MassSpectrometry.CommandModel.Model.ILogListener
    ) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> Any: ...
    def BeginInvoke(
        self,
        cmd: Agilent.MassSpectrometry.CommandModel.Model.ICommand,
        callback: System.AsyncCallback,
        asyncState: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self, cmd: Agilent.MassSpectrometry.CommandModel.Model.ICommand
    ) -> Any: ...

class ICommandPermission(object):  # Interface
    def CheckUserRole(self) -> None: ...

class ICommandPrincipal(object):  # Interface
    def CheckPermission(
        self, command: Agilent.MassSpectrometry.CommandModel.Model.ICommandPermission
    ) -> None: ...
    def HasPermission(
        self, command: Agilent.MassSpectrometry.CommandModel.Model.ICommandPermission
    ) -> bool: ...

class ILogListener(object):  # Interface
    def Log(
        self, cmd: Agilent.MassSpectrometry.CommandModel.Model.ICommand
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import ComponentFilter, ComponentHitID
from .Model import IMainWindow, IUIContext

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF

class ChromatogramViewMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    SelectComponents: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.ChromatogramViewMode
    ) = ...  # static # readonly
    SelectRanges: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.ChromatogramViewMode
    ) = ...  # static # readonly
    Unknown: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.ChromatogramViewMode
    ) = ...  # static # readonly
    WalkChromatogram: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.ChromatogramViewMode
    ) = ...  # static # readonly

class IAddIn(object):  # Interface
    DisplayName: str  # readonly
    Enabled: bool
    Name: str  # readonly
    PathName: str  # readonly

class IAddInManager(object):  # Interface
    Count: int  # readonly
    def __getitem__(
        self, id: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IAddIn
    ): ...
    def GetIDs(self) -> List[str]: ...

class IAnalysisMessageTable(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane,
    System.Windows.Forms.IWin32Window,
):  # Interface
    ...

class IChromatogramPane(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPlotPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane,
    System.Windows.Forms.IWin32Window,
):  # Interface
    ChromatogramViewMode: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.ChromatogramViewMode
    )
    ShowComponents: bool
    ShowEics: bool
    ShowTic: bool

    def ShowPropertiesDialog(self) -> None: ...

class ICompliance(object):  # Interface
    ConnectionTicket: str  # readonly
    IsActive: bool  # readonly
    IsLocal: bool  # readonly
    Name: str  # readonly
    User: str  # readonly

class IComponentTable(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IGridPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane,
    System.Windows.Forms.IWin32Window,
):  # Interface
    CanDeleteComponentsHits: bool  # readonly
    CanExport: bool  # readonly
    CanSetBestHits: bool  # readonly

    def SetColumnVisible(self, columnName: str, visible: bool) -> None: ...
    def ExportToText(
        self,
        allComponents: bool,
        writer: System.IO.TextWriter,
        delimiter: str,
        autoCompoundNames: bool,
        nonHitPrefix: str,
        nonHitAddIndex: bool,
    ) -> None: ...
    def SetBestHits(self) -> None: ...
    def IsColumnVisible(self, columnName: str) -> bool: ...
    def ExportToLibrary(
        self,
        allComponents: bool,
        autoCompoundNames: bool,
        nonHitPrefix: str,
        nonHitAddIndex: bool,
    ) -> None: ...
    def ShowColumnsDialog(self) -> None: ...
    def DeleteComponentsHits(self) -> None: ...
    def RestoreComponentsHits(self) -> None: ...
    def ExportToQuantMethod(
        self,
        destination: str,
        allComponents: bool,
        autoCompoundNames: bool,
        nonHitPrefix: str,
        nonHitAddIndex: bool,
        ionMode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodFromLibraryIonMode,
        numQualifiers: int,
    ) -> None: ...

class IEICPane(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPlotPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane,
    System.Windows.Forms.IWin32Window,
):  # Interface
    def ShowPropertiesDialog(self) -> None: ...

class IExactMassTable(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IGridPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane,
):  # Interface
    def CanShowAlternativeExactMassDialog(self) -> bool: ...
    def ShowAlternativeExactMassDialog(self) -> None: ...
    def ShowColumnsDialog(self) -> None: ...

class IGridPane(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane
):  # Interface
    CanFormatColumn: bool  # readonly

    def FormatColumn(self) -> None: ...

class IIonPeaksPane(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPlotPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane,
    System.Windows.Forms.IWin32Window,
):  # Interface
    ShowComponent: bool
    ShowTIC: bool

    def ShowPropertiesDialog(self) -> None: ...

class IMainForm(System.Windows.Forms.IWin32Window):  # Interface
    ActivePane: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane
    )  # readonly
    AnalysisMessageTable: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IAnalysisMessageTable
    )  # readonly
    ChromatogramPane: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IChromatogramPane
    )  # readonly
    ComponentTable: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IComponentTable
    )  # readonly
    EICPane: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IEICPane
    )  # readonly
    ExactMassTable: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IExactMassTable
    )  # readonly
    IonPeaksPane: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IIonPeaksPane
    )  # readonly
    SampleTable: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.ISampleTable
    )  # readonly
    ScriptPane: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IScriptPane
    )  # readonly
    SpectrumPane: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.ISpectrumPane
    )  # readonly
    StructurePane: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IStructurePane
    )  # readonly
    ToolManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager
    )  # readonly
    _Form: IMainWindow  # readonly

    def Layout(self, layoutNumber: int) -> None: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def Close(self, forceClose: bool) -> None: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def ShowQuery(self, queryFile: str) -> None: ...

class IPane(object):  # Interface
    CanCopy: bool  # readonly
    CanPrint: bool  # readonly
    Visible: bool

    def PageSetup(self) -> None: ...
    def Copy(self) -> None: ...
    def PrintDialog(self) -> None: ...
    def PrintPreview(self) -> None: ...

class IPlotPane(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane
):  # Interface
    CanAutoScaleXY: bool  # readonly
    CanNextZoom: bool  # readonly
    CanPrevZoom: bool  # readonly

    def GetActiveObject(self) -> T: ...
    def AutoScaleXY(self) -> None: ...
    def NextZoom(self) -> None: ...
    def PrevZoom(self) -> None: ...

class IQueryAnalysis(object):  # Interface
    def QuerySamples(
        self, batchID: Optional[int]
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.SampleDataTable
    ): ...
    def QueryBatches(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.BatchDataTable
    ): ...

class ISampleTable(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IGridPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane,
    System.Windows.Forms.IWin32Window,
):  # Interface
    def ShowColumnsDialog(self) -> None: ...

class IScriptEngine(object):  # Interface
    CurrentScope: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IScriptScope
    )  # readonly
    DebugMode: bool  # readonly
    Engine: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptEngine
    )  # readonly
    Globals: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IScriptScope
    )  # readonly

    def CreateScope(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IScriptScope
    ): ...
    def ExecuteFile(
        self,
        file: str,
        scope: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(
        self,
        stream: System.IO.Stream,
        encoding: System.Text.Encoding,
        scope: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(
        self,
        reader: System.IO.TextReader,
        encoding: System.Text.Encoding,
        scope: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IScriptScope,
    ) -> Any: ...

class IScriptInterface(object):  # Interface
    Compliance: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.ICompliance
    )  # readonly
    ScriptEngine: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IScriptEngine
    )  # readonly
    UADataAccess: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUADataAccess
    )  # readonly
    UIState: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState
    )  # readonly
    _ScriptInterface: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IScriptInterface
    )  # readonly

    def _GetPrivateProfileString(
        self, section: str, key: str, defaultValue: str, fileName: str
    ) -> str: ...
    def _WritePrivateProfileString(
        self, section: str, key: str, value_: str, fileName: str
    ) -> int: ...

class IScriptPane(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane
):  # Interface
    def Run(self) -> None: ...
    def Clear(self) -> None: ...

class IScriptScope(object):  # Interface
    def GetVariableNames(self) -> Iterable[str]: ...
    def RemoveVariable(self, name: str) -> None: ...
    def GetVariable(self, name: str) -> Any: ...
    def ContainsVariable(self, name: str) -> bool: ...
    def SetVariable(self, name: str, value_: Any) -> None: ...

class ISpectrumPane(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPlotPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane,
    System.Windows.Forms.IWin32Window,
):  # Interface
    HeadToTail: bool
    ShowExtractedSpectrum: bool

    def ShowPropertiesDialog(self) -> None: ...

class IStructurePane(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane,
    System.Windows.Forms.IWin32Window,
):  # Interface
    ...

class IUADataAccess(object):  # Interface
    def GetBatches(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.BatchDataTable
    ): ...
    def GetLibrarySearchMethods(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.LibrarySearchMethodDataTable
    ): ...
    def GetHits(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.HitDataTable
    ): ...
    def GetPeakQualifier(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.PeakQualifierDataTable
    ): ...
    def GetIonPeak(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.IonPeakDataTable
    ): ...
    def Base64ToDoubleArray(self, base64: str) -> List[float]: ...
    def GetTargetQualifier(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.TargetQualifierDataTable
    ): ...
    def GetPeak(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.PeakDataTable
    ): ...
    def GetTargetMatchMethods(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.TargetMatchMethodDataTable
    ): ...
    def GetAnalysis(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.AnalysisDataTable
    ): ...
    def GetAuxiliaryMethod(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.AuxiliaryMethodDataTable
    ): ...
    def GetComponents(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.ComponentDataTable
    ): ...
    def GetDeconvolutionMethods(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.DeconvolutionMethodDataTable
    ): ...
    def GetIdentificationMethods(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.IdentificationMethodDataTable
    ): ...
    def GetSamples(
        self, batchID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.SampleDataTable
    ): ...
    def GetTargetCompounds(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.TargetCompoundDataTable
    ): ...

class IUIState(object):  # Interface
    ActiveForm: System.Windows.Forms.IWin32Window  # readonly
    ActivePane: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IPane
    )  # readonly
    AddInManager: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IAddInManager
    )  # readonly
    AnalysisFileName: str  # readonly
    BatchFolder: str  # readonly
    BestHitsOnly: bool
    BestPrimaryHitsOnly: bool
    BlankComponent: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ComponentRowID
    )
    BlankSubtractedHits: bool
    CanRedo: bool  # readonly
    CanUndo: bool  # readonly
    ComponentFilter: ComponentFilter
    Constants: Dict[str, str]  # readonly
    ExitCode: int
    FilePath: str  # readonly
    HasAnalysis: bool  # readonly
    IsAuditTrailing: bool  # readonly
    IsDirty: bool  # readonly
    MainForm: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IMainForm
    )  # readonly
    PrimaryHitsOnly: bool
    QueryAnalysis: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IQueryAnalysis
    )  # readonly
    SampleCount: int  # readonly
    ScriptEngine: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IScriptEngine
    )  # readonly
    SelectedComponentHitCount: int  # readonly
    SelectedSampleCount: int  # readonly
    SelectedSamples: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
    ]  # readonly
    SynchronizeInvoke: System.ComponentModel.ISynchronizeInvoke  # readonly
    ToolManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager
    )  # readonly
    UADataAccess: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUADataAccess
    )  # readonly
    _CommandContext: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.CommandContext
    )  # readonly
    _UIContext: IUIContext  # readonly

    def IsSampleSelected(self, batchId: int, sampleId: int) -> bool: ...
    def GetSelectedComponentHits(self) -> Iterable[ComponentHitID]: ...
    def SelectSamples(
        self,
        samples: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
        ],
    ) -> None: ...
    def ShowAuditTrailWindow(self) -> None: ...
    def SelectComponentHits(
        self, chids: Iterable[ComponentHitID], clear: bool
    ) -> None: ...
    @overload
    def RunScript(self, file: str) -> Any: ...
    @overload
    def RunScript(self, stream: System.IO.Stream) -> Any: ...
    def ShowMessage(
        self,
        message: str,
        caption: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
    ) -> System.Windows.Forms.DialogResult: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration

class ApplicationSettings(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationElementSectionBase
):  # Class
    def __init__(self) -> None: ...

    AvailableIntegrators: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.IntegratorType
    ]  # readonly
    DumpLogOnNormalExit: bool  # readonly
    EnableAccurateMassExtension: bool  # readonly
    ErrorReportEmailAddress: str  # readonly
    ScriptReferences: System.Collections.Specialized.StringCollection  # readonly

class ChromatogramSettings(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.PlotUserSettingsSectionBase
):  # Class
    def __init__(self) -> None: ...

    AllowPeakLabelsOverlap: bool
    AutoScaleAfter: float
    AutoScrollX: bool
    AvailablePeakLabelNames: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationStringArrayElement
    )  # readonly
    BlankComponentColor: System.Drawing.Color
    ComponentsColor: System.Drawing.Color
    DefaultAllowPeakLabelsOverlap: bool  # readonly
    DefaultAutoScaleAfter: float  # readonly
    DefaultAutoScrollX: bool  # readonly
    DefaultBlankComponentColor: System.Drawing.Color  # readonly
    DefaultComponentsColor: System.Drawing.Color  # readonly
    DefaultEicColors: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationColorArrayElement
    )  # readonly
    DefaultMaxNumRowsPerPage: int  # readonly
    DefaultPeakLabelsVisible: bool  # readonly
    DefaultSelectedComponentsColor: System.Drawing.Color  # readonly
    DefaultShowComponents: bool  # readonly
    DefaultShowEics: bool  # readonly
    DefaultShowLegend: bool  # readonly
    DefaultShowPeakLabelNames: bool  # readonly
    DefaultShowPeakLabelUnits: bool  # readonly
    DefaultShowSelectedComponents: bool  # readonly
    DefaultShowTic: bool  # readonly
    DefaultSimColor: System.Drawing.Color  # readonly
    DefaultTicColor: System.Drawing.Color  # readonly
    DefaultVerticalPeakLabels: bool  # readonly
    DefaultVisiblePeakLabelColumnNames: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationStringArrayElement
    )  # readonly
    EicColors: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationColorArrayElement
    )  # readonly
    MaxNumRowsPerPage: int
    PeakLabelsVisible: bool
    SelectedComponentsColor: System.Drawing.Color
    ShowComponents: bool
    ShowEics: bool
    ShowLegend: bool
    ShowPeakLabelNames: bool
    ShowPeakLabelUnits: bool
    ShowSelectedComponents: bool
    ShowTic: bool
    SimColor: System.Drawing.Color
    TicColor: System.Drawing.Color
    VerticalPeakLabels: bool
    VisiblePeakLabelColumnNames: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationStringArrayElement
    )  # readonly

class ColorScheme:  # Class
    def __init__(self) -> None: ...

    DisplayName: str
    GraphicsColors: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.GraphicsColorScheme
    )
    Name: str

    def Activate(self) -> None: ...

class ColorSchemeSet:  # Class
    def __init__(self) -> None: ...

    ColorScheme: List[
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColorScheme
    ]

    @staticmethod
    def Load() -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColorSchemeSet
    ): ...
    def GetColorScheme(
        self, name: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColorScheme
    ): ...
    def GetDefaultColorScheme(
        self, isOpenLAB: bool
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColorScheme
    ): ...

class ColumnFormatItem:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        column: str,
        format: Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat,
    ) -> None: ...

    Column: str
    Format: Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat
    _Format: str

class ColumnFormats:  # Class
    def __init__(self) -> None: ...

    Formats: List[
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnFormatItem
    ]

    def HasAccurateMassFormat(self, column: str) -> bool: ...
    def Initialize(self) -> None: ...
    def GetDefaultFormat(
        self, column: str, isAccurateMass: bool
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat: ...
    def SaveFormats(self) -> None: ...
    def SetFormat(
        self,
        column: str,
        isAccurateMass: bool,
        value_: Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat,
    ) -> None: ...
    def Clear(self) -> None: ...
    def GetFormat(
        self, column: str, isAccurateMass: bool
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat: ...

class ColumnWidthItem:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, column: str, width: int) -> None: ...

    Column: str
    Width: int

class ColumnWidths:  # Class
    def __init__(self) -> None: ...
    def __getitem__(self, column: str) -> Optional[int]: ...
    def __setitem__(self, column: str, value_: Optional[int]) -> None: ...
    Widths: List[
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidthItem
    ]

class EicPeaksSettings(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.PlotUserSettingsSectionBase
):  # Class
    def __init__(self) -> None: ...

    DefaultShowTic: bool  # readonly
    DefaultTicColor: System.Drawing.Color  # readonly
    ShowTic: bool
    TicColor: System.Drawing.Color

class GraphicsColorScheme:  # Class
    def __init__(self) -> None: ...

    BackColor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    ComponentColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    ForeColor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    IonPeakColors: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    ]
    SpectrumColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    TicColor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor

    def Activate(self) -> None: ...

class IonPeaksSettings(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.PlotUserSettingsSectionBase
):  # Class
    def __init__(self) -> None: ...

    ComponentColor: System.Drawing.Color
    DefaultComponentColor: System.Drawing.Color  # readonly
    DefaultIonPeakColors: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationColorArrayElement
    )  # readonly
    DefaultNumVisibleIonPeaks: int  # readonly
    DefaultShowComponent: bool  # readonly
    DefaultShowTic: bool  # readonly
    DefaultTicColor: System.Drawing.Color  # readonly
    IonPeakColors: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationColorArrayElement
    )  # readonly
    MaxNumVisibleIonPeaks: int  # readonly
    NumVisibleIonPeaks: int
    ShowComponent: bool
    ShowTic: bool
    TicColor: System.Drawing.Color

class NumericFormat(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericFormat
):  # Class
    def __init__(
        self,
        formats: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnFormats,
    ) -> None: ...

    IsAccurateMass: bool

class PlotUserSettingsSectionBase(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.UserSettingsSectionBase
):  # Class
    def __init__(self) -> None: ...

    BackgroundColor: System.Drawing.Color
    DefaultBackgroundColor: System.Drawing.Color  # readonly
    DefaultFontBold: bool  # readonly
    DefaultFontFamily: str  # readonly
    DefaultFontItalic: bool  # readonly
    DefaultFontSize: float  # readonly
    DefaultForegroundColor: System.Drawing.Color
    DefaultGridlinesColor: System.Drawing.Color  # readonly
    DefaultShowGridlines: bool  # readonly
    FontBold: bool
    FontFamily: str
    FontItalic: bool
    FontSize: float
    ForegroundColor: System.Drawing.Color
    GridlinesColor: System.Drawing.Color
    PrintPageSettings: str
    ShowGridlines: bool

class SpectrumSettings(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.PlotUserSettingsSectionBase
):  # Class
    def __init__(self) -> None: ...

    AllowPeakLabelsOverlap: bool
    DefaultAllowPeakLabelsOverlap: bool  # readonly
    DefaultFoundExactMassColor: System.Drawing.Color  # readonly
    DefaultHeadToTail: bool  # readonly
    DefaultSelectedExactMassColor: System.Drawing.Color  # readonly
    DefaultShowExtractedSpectrum: bool  # readonly
    DefaultShowPeakLabels: bool  # readonly
    DefaultSpectrumColor: System.Drawing.Color  # readonly
    DefaultVerticalPeakLabels: bool  # readonly
    FoundExactMassColor: System.Drawing.Color
    HeadToTail: bool
    SelectedExactMassColor: System.Drawing.Color
    ShowExtractedSpectrum: bool
    ShowPeakLabels: bool
    SpectrumColor: System.Drawing.Color
    VerticalPeakLabels: bool

class StructureSettings(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.UserSettingsSectionBase
):  # Class
    def __init__(self) -> None: ...

    PrintPageSettings: str

class UAConfiguration:  # Class
    ApplicationSettings: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ApplicationSettings
    )  # readonly
    ChromatogramSettings: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ChromatogramSettings
    )  # readonly
    EicPeaksSettings: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.EicPeaksSettings
    )  # readonly
    Initialized: bool  # readonly
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.UAConfiguration
    )  # static # readonly
    IonPeaksSettings: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.IonPeaksSettings
    )  # readonly
    Location: str  # readonly
    SpectrumSettings: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.SpectrumSettings
    )  # readonly
    StructureSettings: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.StructureSettings
    )  # readonly
    UserSettings: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.UserSettings
    )  # readonly

    def Initialize(self) -> None: ...
    @overload
    @staticmethod
    def GetHeaderText(table: str, column: str) -> str: ...
    @overload
    @staticmethod
    def GetHeaderText(column: str) -> str: ...
    @staticmethod
    def _GetHeaderText(column: str) -> str: ...
    def Save(self) -> None: ...

class UserSettings(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationElementSectionBase
):  # Class
    def __init__(self) -> None: ...

    AlwaysReanalyze: bool
    ColumnFormats: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnFormats
    )  # readonly
    ColumnWidthsAdvancedAuxiliary: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsAdvancedBlankSubtraction: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsAdvancedDeconvolution: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsAdvancedIdentification: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsAdvancedLibrarySearch: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsAdvancedTargetMatch: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsAnalysisMessageTable: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsComponentTable: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsHitTable: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsLoadMethodDialog: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsSampleTable: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ColumnWidthsTargetTable: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Configuration.ColumnWidths
    )
    ExportComponentsAllComponents: bool
    ExportComponentsTo: str
    GenerateReportNow: bool
    LastAnalysisFolder: str
    LastEnableAuditTrail: bool
    LastExportFolder: str
    LastLayoutFolder: str
    LastLibraryFolder: str
    LastMethodFolder: str
    LastMethodPane: str
    LastQueryFolder: str
    LastRTCalibrationFolder: str
    LastReportMethod: str
    LastScriptFolder: str
    LinqDebug: bool
    LinqTraceCode: bool
    LoadMethodDialogClientSize: System.Drawing.Size
    MethodAdvancedDialogClientSize: System.Drawing.Size
    NonHitAutoCompoundNames: bool
    NonHitCompoundNameAddIndex: bool
    NonHitCompoundNamePrefix: str
    OpenReportFolder: bool
    PrintLandscape: bool
    RecentAnalysisFiles: System.Collections.Specialized.StringCollection  # readonly
    ReportAllSamples: bool
    ShowAdvancedMethod: bool
    StartQueueViewer: bool
    VisibleColumnsComponentTable: System.Collections.Specialized.StringCollection
    VisibleColumnsExactMassTable: System.Collections.Specialized.StringCollection
    VisibleColumnsSampleTable: System.Collections.Specialized.StringCollection
    VisibleColumnsTargetTable: System.Collections.Specialized.StringCollection

    def GetValue(self, name: str, defaultValue: T) -> T: ...
    def GetOpenReportFolder(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> bool: ...
    def SetValue(self, name: str, value_: T) -> None: ...

class UserSettingsSectionBase(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationElementSectionBase
):  # Class
    def __init__(self) -> None: ...

    StandardFontSizes: List[Any]  # static # readonly

    @staticmethod
    def SetPlotFont(
        plot: Agilent.MassSpectrometry.GUI.Plot.PlotControl,
        fontFamily: str,
        size: float,
        bold: bool,
        italic: bool,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import GraphicsControls, InsertList, InsertTable

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI

class CustomUI(Agilent.MassHunter.ReportBuilder.DataSource.ICustomUI):  # Class
    def __init__(
        self,
        dataSourceDesigner: Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceDesigner,
    ) -> None: ...
    def CanExecuteSystemCommand(
        self,
        app: Agilent.MassHunter.ReportBuilder.Application.IApplication,
        cmdid: str,
        parameter: Any,
        canExecute: bool,
    ) -> bool: ...
    def ExecuteSystemCommand(
        self,
        app: Agilent.MassHunter.ReportBuilder.Application.IApplication,
        cmdid: str,
        parameter: Any,
    ) -> bool: ...
    def GetCustomCommandGroups(
        self, application: Agilent.MassHunter.ReportBuilder.Application.IApplication
    ) -> List[Agilent.MassHunter.ReportBuilder.DataSource.ICustomCommandGroup]: ...

class IWizardViewModel(object):  # Interface
    def ButtonPushed(
        self,
        button: Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.WizardButton,
    ) -> None: ...
    def ButtonEnabled(
        self,
        button: Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.WizardButton,
    ) -> bool: ...

    ButtonChanged: System.EventHandler  # Event

class NotifyPropertyChangedBase(System.ComponentModel.INotifyPropertyChanged):  # Class
    def VerifyPropertyName(self, propertyName: str) -> None: ...

    PropertyChanged: System.ComponentModel.PropertyChangedEventHandler  # Event

class RelayCommand(System.Windows.Input.ICommand):  # Class
    @overload
    def __init__(self, execute: System.Action) -> None: ...
    @overload
    def __init__(
        self, execute: System.Action, canExecute: System.Predicate
    ) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def RaiseCanExecuteChanged(self) -> None: ...
    def Execute(self, parameter: Any) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class Utils:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GetUniqueBindingName(
        container: Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer,
        name: str,
    ) -> str: ...
    @staticmethod
    def FindBindingName(
        container: Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer,
        name: str,
    ) -> Agilent.MassHunter.ReportBuilder.DataModel.IDataBindingContainer: ...
    @staticmethod
    def FindParentBindingContainer(
        container: Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer,
        dataName: str,
        binding: Agilent.MassHunter.ReportBuilder.DataModel.IDataBinding,
    ) -> Agilent.MassHunter.ReportBuilder.DataModel.IDataBindingContainer: ...

class WizardButton(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Back: Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.WizardButton = (
        ...
    )  # static # readonly
    Cancel: Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.WizardButton = (
        ...
    )  # static # readonly
    Finish: Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.WizardButton = (
        ...
    )  # static # readonly
    Next: Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.WizardButton = (
        ...
    )  # static # readonly

class WizardResult(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Canceled: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.WizardResult
    ) = ...  # static # readonly
    Finished: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.WizardResult
    ) = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Compliance import ICompliance

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask

class CancelSignalDetectedException(
    System.ApplicationException,
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class IQueuedTask(
    System.Xml.Serialization.IXmlSerializable, System.IDisposable
):  # Interface
    Actions: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskAction
    ]  # readonly
    CancelEventName: str
    Context: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskContext
    )
    ProcessingPriority: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.TaskPriority
    )
    TaskDescription: str  # readonly
    TaskLockName: str  # readonly
    TaskName: str  # readonly

    def Process(self) -> None: ...

class IQueuedTaskAction(object):  # Interface
    DisplayName: str  # readonly

    def Execute(self, parent: System.Windows.Forms.IWin32Window) -> None: ...

class IQueuedTaskContext(object):  # Interface
    Compliance: ICompliance  # readonly

class IQueuedTaskNotification(
    System.Xml.Serialization.IXmlSerializable, System.IDisposable
):  # Interface
    def OnSubTaskStart(
        self,
        task: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    ) -> None: ...
    def OnTaskFinish(self) -> None: ...
    def OnTaskError(self, message: str, e: System.Exception) -> None: ...
    def OnTaskStart(self, queuedFile: str) -> None: ...
    def OnSubTaskFinish(self) -> None: ...

class LockTasks(System.IDisposable):  # Class
    def __init__(self, lockNames: List[str]) -> None: ...
    def CanStart(self) -> bool: ...
    def Dispose(self) -> None: ...
    def Unlock(self) -> None: ...
    def Lock(self) -> None: ...

class OpenDirectoryTaskAction(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskAction,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.OpenFileTaskAction,
):  # Class
    def __init__(self, directory: str) -> None: ...

    DisplayName: str  # readonly

class OpenFileTaskAction(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskAction
):  # Class
    def __init__(self, file: str) -> None: ...

    DisplayName: str  # readonly

    def Execute(self, parent: System.Windows.Forms.IWin32Window) -> None: ...

class QueuedTaskConfiguration:  # Class
    LogDirectory: str  # static # readonly
    QueueDirectory: str  # static
    ServiceType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.ServiceType
    )  # static # readonly
    TaskNotificationSettings: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.QueuedTaskNotificationSetting
    ]  # static # readonly
    WatchDirectory: str  # static
    WriteTaskLog: bool  # static # readonly

    @staticmethod
    def GenerateQueueFileName(nameBase: str) -> str: ...
    @overload
    @staticmethod
    def GetFullPathName(path: str) -> str: ...
    @overload
    @staticmethod
    def GetFullPathName(assembly: System.Reflection.Assembly, path: str) -> str: ...

class QueuedTaskContext(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskContext
):  # Class
    def __init__(self) -> None: ...

    Compliance: ICompliance

class QueuedTaskException(
    System.ApplicationException,
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class QueuedTaskNotificationSetting(System.Configuration.ConfigurationElement):  # Class
    def __init__(self) -> None: ...

    Name: str
    Type: str

class QueuedTaskNotificationSettingCollection(
    Iterable[Any], System.Configuration.ConfigurationElementCollection, Sequence[Any]
):  # Class
    def __init__(self) -> None: ...

class QueuedTaskSettingsSection(System.Configuration.ConfigurationSection):  # Class
    def __init__(self) -> None: ...

    LogDirectory: str
    QueueDirectory: str
    ServiceNotifications: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.QueuedTaskNotificationSettingCollection
    )  # readonly
    ServiceType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.ServiceType
    )
    WatchDirectory: str
    WriteTaskLog: bool

class QueuedTasks(System.Xml.Serialization.IXmlSerializable):  # Class
    def __init__(self) -> None: ...

    Completion: System.DateTime
    Notifications: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskNotification
    ]
    Tasks: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask
    ]

    def Cleanup(self) -> None: ...

class ServiceType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    LocalProcess: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.ServiceType
    ) = ...  # static # readonly
    LocalService: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.ServiceType
    ) = ...  # static # readonly
    RemoteUserProcess: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.ServiceType
    ) = ...  # static # readonly
    RemoteWindowsService: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.ServiceType
    ) = ...  # static # readonly

class TaskPriority(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    High: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.TaskPriority = (
        ...
    )  # static # readonly
    Low: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.TaskPriority = (
        ...
    )  # static # readonly
    Normal: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.TaskPriority
    ) = ...  # static # readonly

class TaskQueue:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def WriteTaskCompletionTime(taskFile: str, completion: System.DateTime) -> None: ...
    @staticmethod
    def LoadTaskLockNames(stream: System.IO.Stream) -> List[str]: ...
    @staticmethod
    def CreateTask(
        type: System.Type,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask: ...
    @staticmethod
    def ReadTaskCompletionTime(taskFile: str) -> System.DateTime: ...
    @staticmethod
    def ProcessTasksInSeparateDomain(
        queuedFile: str, cancelEventName: str, logFilePath: str
    ) -> None: ...
    @staticmethod
    def PushTasks(
        name: str,
        notifications: List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskNotification
        ],
        tasks: List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask
        ],
    ) -> None: ...
    @staticmethod
    def LoadTasks(
        stream: System.IO.Stream,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.QueuedTasks: ...

    # Nested Types

    class TaskStarter(System.MarshalByRefObject):  # Class
        def __init__(self) -> None: ...
        def Start(
            self, queuedFile: str, cancelEventName: str, logFilePath: str
        ) -> None: ...

class TaskQueueType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    FileWatcher: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.TaskQueueType
    ) = ...  # static # readonly
    MSMQ: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.TaskQueueType
    ) = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Themes.Microsoft

class CloseWindowCommand(System.Windows.Input.ICommand):  # Class
    def __init__(self) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def Execute(self, parameter: Any) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class DialogWindowBehavior:  # Class
    LeftMouseButtonDrag: System.Windows.DependencyProperty  # static # readonly

    @staticmethod
    def GetLeftMouseButtonDrag(
        obj: System.Windows.DependencyObject,
    ) -> System.Windows.UIElement: ...
    @staticmethod
    def SetLeftMouseButtonDrag(
        obj: System.Windows.DependencyObject, window: System.Windows.UIElement
    ) -> None: ...

class ToolbarMenuItem(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Input.ICommandSource,
    System.Windows.Markup.IQueryAmbient,
    MS.Internal.Controls.IGeneratorHost,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    System.Windows.IInputElement,
    System.Windows.Controls.MenuItem,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.Controls.Primitives.IContainItemStorage,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...

    HeaderVisibilityProperty: System.Windows.DependencyProperty  # static # readonly
    IconVisibilityProperty: System.Windows.DependencyProperty  # static # readonly

    HeaderVisibility: System.Windows.Visibility
    IconVisibility: System.Windows.Visibility



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import FileDialog, NewBatch, OpenBatch, SaveAs, SplashScreen

# Stubs for namespace: Agilent.MassHunter.Quantitative.Controls

class BindingProxy(System.Windows.ISealable, System.Windows.Freezable):  # Class
    def __init__(self) -> None: ...

    DataProperty: System.Windows.DependencyProperty  # static # readonly

    Data: Any

class BindingUtils:  # Class
    @staticmethod
    def ClearAllDescendentBindings(
        dependencyObject: System.Windows.DependencyObject,
    ) -> None: ...
    @staticmethod
    def EnumerateVisualChildren(
        dependencyObject: System.Windows.DependencyObject,
    ) -> Iterable[System.Windows.DependencyObject]: ...
    @staticmethod
    def EnumerateVisualDescendents(
        dependencyObject: System.Windows.DependencyObject,
    ) -> Iterable[System.Windows.DependencyObject]: ...

class DelegateCommand(System.Windows.Input.ICommand):  # Class
    @overload
    def __init__(self, exec: System.Action) -> None: ...
    @overload
    def __init__(
        self, exec: System.Action, canExec: System.Func[Any, bool]
    ) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def Execute(self, parameter: Any) -> None: ...
    def NotifyCanExecuteChanged(self, e: System.EventArgs) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class DropDownButton(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    System.Windows.Input.ICommandSource,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Controls.Primitives.ToggleButton,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    Items: System.Windows.Controls.ItemCollection  # readonly

    def InitializeComponent(self) -> None: ...

class Extensions:  # Class
    @staticmethod
    def FormatWith(s: str, args: List[Any]) -> str: ...

class HeaderedSeparator(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.Control,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IFrameworkInputElement,
):  # Class
    def __init__(self) -> None: ...

    HeaderProperty: System.Windows.DependencyProperty  # static

    Header: str

class HintedTextBox(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    System.Windows.Controls.ITextBoxViewHost,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.TextBox,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    EnterKeyCommandParameterProperty: (
        System.Windows.DependencyProperty
    )  # static # readonly
    EnterKeyCommandProperty: System.Windows.DependencyProperty  # static # readonly
    HintTextColorProperty: System.Windows.DependencyProperty  # static # readonly
    HintTextProperty: System.Windows.DependencyProperty  # static # readonly

    EnterKeyCommand: System.Windows.Input.ICommand
    EnterKeyCommandParameter: Any
    HintText: str
    HintTextColor: System.Windows.Media.Color

    def InitializeComponent(self) -> None: ...

class IApplicationMenu2010Content(object):  # Interface
    def SetSize(self, width: float, height: float) -> None: ...

class ImageConverter(System.Windows.Data.IValueConverter):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, color: System.Windows.Media.Color) -> None: ...

    Color: System.Windows.Media.Color

    @overload
    @staticmethod
    def ConvertImage(
        image: System.Windows.Media.Imaging.BitmapSource,
        color: System.Windows.Media.Color,
    ) -> System.Windows.Media.Imaging.BitmapSource: ...
    @overload
    @staticmethod
    def ConvertImage(
        image: System.Windows.Media.Imaging.BitmapSource,
    ) -> System.Windows.Media.Imaging.BitmapSource: ...
    def ConvertBack(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...
    def Convert(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...

class InverseBooleanConverter(System.Windows.Data.IValueConverter):  # Class
    def __init__(self) -> None: ...
    def ConvertBack(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...
    def Convert(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...

class InverseBooleanToVisibilityConverter(System.Windows.Data.IValueConverter):  # Class
    def __init__(self) -> None: ...
    def ConvertBack(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...
    def Convert(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...

class PathTrimmingConverter(System.Windows.Data.IMultiValueConverter):  # Class
    def __init__(self) -> None: ...
    def ConvertBack(
        self,
        value_: Any,
        targetTypes: List[System.Type],
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> List[Any]: ...
    def Convert(
        self,
        values: List[Any],
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...

class ResxStringConverter(System.Windows.Data.IValueConverter):  # Class
    def __init__(self) -> None: ...
    def ConvertBack(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...
    def Convert(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...

class ResxStringLocalizer:  # Class
    def __init__(self, pathBase: str) -> None: ...
    def GetString(
        self, name: str, culture: System.Globalization.CultureInfo
    ) -> str: ...

class SHFILEINFO:  # Struct
    dwAttributes: int
    hIcon: System.IntPtr
    iIcon: int
    szDisplayName: str
    szTypeName: str

class ShellFileInfo:  # Class
    def __init__(self) -> None: ...

    CSIDL_DRIVES: int = ...  # static # readonly
    SHGFI_DISPLAYNAME: int = ...  # static # readonly
    SHGFI_ICON: int = ...  # static # readonly
    SHGFI_LARGEICON: int = ...  # static # readonly
    SHGFI_SMALLICON: int = ...  # static # readonly

    @staticmethod
    def GetFileInfo(
        pathname: str, flags: int
    ) -> Agilent.MassHunter.Quantitative.Controls.SHFILEINFO: ...
    @staticmethod
    def GetFileInfoFromExtension(ext: str) -> System.IntPtr: ...

    # Nested Types

    class NativeMethods:  # Class
        def __init__(self) -> None: ...
        @staticmethod
        def SHGetFileInfo(
            pszPath: str,
            dwFileAttributes: int,
            psfi: Agilent.MassHunter.Quantitative.Controls.SHFILEINFO,
            cbSizeFileInfo: int,
            uFlags: int,
        ) -> System.IntPtr: ...
        @staticmethod
        def DestroyIcon(handle: System.IntPtr) -> bool: ...
        @staticmethod
        def ExtractIconEx(
            szFileName: str,
            nIconIndex: int,
            phiconLarge: List[System.IntPtr],
            phiconSmall: List[System.IntPtr],
            nIcons: int,
        ) -> int: ...
        @staticmethod
        def SHGetFolderPath(
            hwndOwner: System.IntPtr,
            nFolder: int,
            hToken: System.IntPtr,
            dwFlags: int,
            pszPath: System.Text.StringBuilder,
        ) -> int: ...

class SplitToolButton(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    System.Windows.Input.ICommandSource,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Controls.Primitives.ToggleButton,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    Items: System.Windows.Controls.ItemCollection  # readonly

    def InitializeComponent(self) -> None: ...

class TextInputToVisibilityConverter(System.Windows.Data.IMultiValueConverter):  # Class
    def __init__(self) -> None: ...
    def ConvertBack(
        self,
        value_: Any,
        targetTypes: List[System.Type],
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> List[Any]: ...
    def Convert(
        self,
        values: List[Any],
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...

class WpfWin32Window(System.Windows.Forms.IWin32Window):  # Class
    def __init__(self, wpfWindow: System.Windows.Window) -> None: ...

    Handle: System.IntPtr  # readonly



from typing import List, Optional, Tuple

import os
import subprocess
import sys
from collections.abc import Iterable
from enum import Enum, auto
from pathlib import Path
from tempfile import NamedTemporaryFile

from ..legacy.common import __DEFAULT_MH_BIN_DIR__ as _DEFAULT_MH_BIN_DIR
from .common import logger, set_logger_level

# fmt: off
__DEFAULT_MH_BIN_DIR__ = Path(_DEFAULT_MH_BIN_DIR)
__DEFAULT_PY275_EXE__ = Path("C:/") / "Program Files (x86)" / "IronPython 2.7" / "ipy.exe"
# fmt: on


def get_absolute_executable_path(
    interpreter: Path,
    cwd: Path | None = None,
) -> Path:
    exe_path = Path(interpreter)

    if exe_path.exists():
        logger.debug("direct found executable")
        return exe_path.absolute()
    if (
        cwd is not None
        and not exe_path.is_absolute()
        and (Path(cwd) / interpreter).exists()
    ):
        logger.debug("found executable under relative path")
        return (Path(cwd) / interpreter).absolute()

    # fmt: off
    alias = {
        "ipy": __DEFAULT_PY275_EXE__,
        "ipy.exe": __DEFAULT_PY275_EXE__,
        "python2": Path("/usr/bin/python2") if sys.platform == 'linux' else __DEFAULT_PY275_EXE__,

        "UAC": __DEFAULT_MH_BIN_DIR__ / "UnknownsAnalysisII.Console.exe",
        "UnknownsAnalysisII.Console": __DEFAULT_MH_BIN_DIR__ / "UnknownsAnalysisII.Console.exe",
        "UnknownsAnalysisII.Console.exe": __DEFAULT_MH_BIN_DIR__ / "UnknownsAnalysisII.Console.exe",

        "LEC": __DEFAULT_MH_BIN_DIR__ / "LibraryEdit.Console.exe",
        "LibraryEdit.Console": __DEFAULT_MH_BIN_DIR__ / "LibraryEdit.Console.exe",
        "LibraryEdit.Console.exe": __DEFAULT_MH_BIN_DIR__ / "LibraryEdit.Console.exe",

        "QC": __DEFAULT_MH_BIN_DIR__ / "QuantConsole.exe",
        "QuantConsole": __DEFAULT_MH_BIN_DIR__ / "QuantConsole.exe",
        "QuantConsole.exe": __DEFAULT_MH_BIN_DIR__ / "QuantConsole.exe",
    }
    # fmt: on
    exe_path = alias.get(str(interpreter), None)
    if exe_path is not None and exe_path.exists():
        logger.debug("found executable with alias")
        return exe_path
    raise SystemError(f"Error: IronPython executable not found at '{interpreter}'")


class CaptureType(Enum):
    NONE = auto()
    STDOUT = auto()
    STDERR = auto()
    BOTH = auto()
    SEPERATE = auto()


def run_ironpython_script(
    script_path: Path,
    interpreter: Path = __DEFAULT_PY275_EXE__,
    cwd: Path | None = None,
    python_paths: Iterable[str] | None = None,
    extra_envs: Iterable[str] | None = None,
    script_args: Iterable[str] | None = None,
    capture_type: CaptureType = CaptureType.STDOUT,
) -> tuple[int, str | None, str | None]:
    """
    Runs an IronPython script using the subprocess module.

    Args:
        script_path (Path): Path to the IronPython script (.py) to execute.
        interpreter (Path): Path to the IronPython-like executable (e.g., ipy.exe).
        cwd (str, optional): The working directory for the subprocess.
                             Defaults to the current working directory.
        python_paths (list, optional): A list of additional paths to add to
                                       IronPython's sys.path (like PYTHONPATH).
        extra_envs (list, optional): A list of additional envrionments to prepend to
                                       copy of os.environ.
        script_args (list, optional): A list of command-line arguments to pass
                                      to the IronPython script itself.
        capture_type (CaptureType): The stdout/stderr capture for returned values.

    Returns:
        tuple: A tuple containing (return_code, stdout, stderr).

    Raises:
        SystemError: Usually because of FileNotFoundError on interperater/script

    """

    # The script_path do not respect cwd specified, always use current real working directory
    if not Path(script_path).exists():
        raise SystemError(f"Error: IronPython script not found at '{script_path}'")
    script_abs_path = str(Path(script_path).absolute())
    if not Path(interpreter).exists():
        raise SystemError(f"Error: IronPython interpreter not found at '{interpreter}'")
    interpreter_abs_path = str(Path(interpreter).absolute())

    # relative executable path can be infered by specified cwd when not found under current directory
    cwd = Path("." if cwd is None else cwd).absolute()
    assert Path(cwd).is_dir()

    env = os.environ.copy()

    # extra environment have higher priority than those specified from outside in current process
    if extra_envs:
        for e in extra_envs:
            k, v = e.split("=", maxsplit=1)
            assert str.isidentifier(k)
            env[k] = v

    if script_args is None:
        script_args = []
    # For MassHunter executable, passing args as envrionments
    if interpreter.parts[-5:-1] == __DEFAULT_MH_BIN_DIR__.parts[-4:]:
        command = [interpreter_abs_path, f"-script={script_abs_path}"]
        assert env.setdefault(f"MH_CONSOLE_ARGS_0", script_abs_path) == script_abs_path
        for i, arg in enumerate(script_args):
            # One would better not specify environment MH_CONSOLE_ARGS_* from outside
            assert env.setdefault(f"MH_CONSOLE_ARGS_{i+1}", arg) == arg
        script_args = []
    else:
        command = [interpreter_abs_path, script_abs_path, *script_args]

    if python_paths:
        env["PYTHONPATH"] = os.pathsep.join(
            [*python_paths, env.get("PYTHONPATH", "")]
        ).strip(os.pathsep)

    command = [str(c) for c in command]
    logger.debug(
        "\n".join(
            (
                f"--- Running IronPython Script ---",
                f"Executable: {interpreter_abs_path}",
                f"Script:     {script_abs_path}",
                f"Arguments:  {script_args}",
                f"CWD:        {cwd}",
                f"Command:    {' '.join(command)}",
            )
        )
    )

    capture_args = {
        CaptureType.NONE: dict(),
        CaptureType.STDOUT: dict(stdout=subprocess.PIPE),
        CaptureType.STDERR: dict(stderr=subprocess.PIPE),
        CaptureType.BOTH: dict(stdout=subprocess.PIPE, stderr=subprocess.STDOUT),
        CaptureType.SEPERATE: dict(stdout=subprocess.PIPE, stderr=subprocess.PIPE),
    }.get(capture_type, {})

    process = subprocess.run(
        command, cwd=cwd, env=env, text=True, check=False, **capture_args
    )

    result = (
        process.returncode,
        (process.stdout if "stdout" in capture_args else None),
        (process.stderr if "stderr" in capture_args else None),
    )

    logger.debug(
        "\n".join(
            (
                f"--- IronPython Output (stdout) ---",
                f"{result[1]}",
                f"--- IronPython Output (stderr) ---",
                f"{result[2]}",
                f"--- IronPython process finished with exit code: {result[0]} ---",
            )
        )
    )

    return result


import click


@click.command()
@click.argument(
    "script_args",
    type=str,
    nargs=-1,
)
@click.option(
    "--command",
    help="The temporary script contents, the first arg will no longer be treated as script pass.",
)
@click.option(
    "--interpreter",
    default="python2",
    type=str,
    help="Path to the IronPython executable (e.g., ipy.exe or /usr/bin/ipy).",
)
@click.option(
    "--cwd",
    default=Path(".").absolute(),
    type=click.Path(exists=True, file_okay=False, resolve_path=True),
    show_default=False,
    help="Working directory for the IronPython process.",
)
@click.option(
    "--python-path",
    type=click.Path(exists=True, resolve_path=True),
    default=[Path(".").absolute()],
    multiple=True,
    help="Additional paths to add to the IronPython environment's PYTHONPATH.",
)
@click.option(
    "--env",
    multiple=True,
    type=str,
    help="Additional envrionments",
)
@click.option(
    "--log-level",
    type=click.Choice(["DEBUG", "INFO", "WARNING", "ERROR"], case_sensitive=False),
    default="INFO",
    help="Set the logging verbosity",
)
def main(
    script_args: list[str],
    command: str | None = None,
    interpreter: Path = __DEFAULT_PY275_EXE__,
    cwd: Path | None = None,
    python_path: list[str] | None = None,
    env: list[str] | None = None,
    log_level: str = "INFO",
):
    """Runs an IronPython script using the subprocess module.
    Command text must be provided or the first argument will be treated as the script path.
    Script path `-` will be read from stdin.

    Example:

        shebang --interpreter LEC --command "import sys; print sys.version"

        shebang - <<< "import sys; print sys.version"
    """
    set_logger_level(log_level)

    if command is None and script_args:
        script, *script_args = script_args
    else:
        script = "-"

    is_temp_script = script == "-"

    if is_temp_script:
        with NamedTemporaryFile("w", suffix=".py", delete=False) as fp:
            script = fp.name
            if command is None:
                click.secho(
                    f"Reading from stdin into {script}",
                    fg="green",
                )
                fp.write(sys.stdin.read())
            else:
                fp.write(command)

    try:
        returncode, _, _ = run_ironpython_script(
            interpreter=get_absolute_executable_path(interpreter, cwd),
            script_path=Path(script),
            cwd=cwd,
            python_paths=python_path,
            extra_envs=env,
            script_args=script_args,
            capture_type=CaptureType.NONE,
        )

        if returncode != 0:
            click.secho(
                f"Processing failed for {script} with return code {returncode}",
                fg="red",
                err=True,
            )
            raise click.Abort()
    finally:
        if is_temp_script:
            Path(script).unlink()


if __name__ == "__main__":
    main()
